import os
import datasets
import numpy as np

from fewshot_gym_dataset import FewshotGymDataset, FewshotGymTextToTextDataset


class AdeCorpusV2_Dosage(FewshotGymTextToTextDataset):
    def __init__(self):
        self.hf_identifier = "ade_corpus_v2-dosage"
        self.task_type = "text to text"
        self.license = "unknown"

    def get_train_test_lines(self, dataset):
        # only train set, manually split 20% data as test
        lines = self.map_hf_dataset_to_list(dataset, "train")

        np.random.seed(42)
        np.random.shuffle(lines)

        n = len(lines)

        train_lines = lines[: int(0.8 * n)]
        test_lines = lines[int(0.8 * n) :]

        return train_lines, test_lines

    def map_hf_dataset_to_list(self, hf_dataset, split_name):
        lines = []
        for datapoint in hf_dataset[split_name]:
            lines.append(
                (datapoint["text"] + " [SEP] " + datapoint["drug"], datapoint["dosage"])
            )
        return lines

    def load_dataset(self):
        return datasets.load_dataset(
            "ade_corpus_v2", "Ade_corpus_v2_drug_dosage_relation"
        )


def main():
    dataset = AdeCorpusV2_Dosage()

    for seed in [100, 13, 21, 42, 87]:
        train, dev, test = dataset.generate_k_shot_data(seed=seed, path="../data/")


if __name__ == "__main__":
    main()
